==> domcom-0.2.1.tgz: package/doc/Chinese/文件夹和模块介绍.md <==
# 代码文件夹及模块介绍

## 核心文件夹：src/core/
  部件相关的代码，包含部件基类及派生类定义、部件相关及特性相关辅助工具函数、实例化函数及Html标签函数

### 部件类文件夹：src/core/base/

  以下各组件都有各自单独对应的模块文件。

  > 部件基类：Component, BaseComponent, TransformComponent

  > 基础部件类：Tag, List, Tag, Text, Html, Comment
  
  > 变换部件类：If,Case, Cond, Func, Each, Route, Defer
  update(2016-3-16):Each部件已经被移除，直接用every, each, funcEach和mapEach函数，生成响应式List部件。
 
  > 辅助函数：toComponent和isComponent

### 部件实例化函数文件：src/core/instantiate
 > tag, txt, comment, html, if_, case_, cond, func, list, each, every, all, nTimes
 update(2016-3-16): all, nTimes已经被移除。

### 标签部件实例化函数模块文件：src/core/tag
 Html标签：
 
 > a abbr acronym address area b base bdo big blockquote body br button caption cite code col colgroup dd del dfn div dl dt em fieldset form h1 h2 h3 h4 h5 h6 head html hr i img input ins kbd label legend li link map meta noscript object ol optgroup option p param pre q samp script select small span strong style sub sup table tbody td textarea tfoot th thead title tr tt ul var header footer section

  > 不同类型的input标签函数：text, checkbox, radio, date, email, number

  更准确完整的列表请参考domcom/src/core/tag.coffee。如果有错误或者遗漏请作为bug在github issues中予以提出。

### Tag特性工具函数模块文件：src/core/property

  > classFn, styleFrom, extendAttrs, extendEventValue

*********************************************************************************************

## 文件夹：src/flow/

  包含响应函数相关代码，例如各种响应函数产生器以及其它辅助工具函数。


### 基本响应函数模块文件：src/flow/index
  本文件包含以下函数：

  > react, renewm dependent, flow, pipe, see, seeN, bind, duplex, unary, binary

### Each部件相关响应函数模块：src/flow/watch-list

  > watchEachList和watchEachObject

### 增补响应函数模块文件：src/flow/addon

  > 自动绑定：bindings
  
  > 一元运算：neg， no， bitnot， reciprocal，abs， floor，ceil， round
  
  > 二元运算：add， sub，mul，div，min
  
  > 三目运算： if_

*********************************************************************************

## 源代码根文件夹：src/

  以下直属src/文件夹的各模块包含了常用的Domcom辅助工具函数。

### DomNode类模块文件：src/DomNode

### dc直属工具函数模块文件：src/dc

  > dc, dc.directives, dc.onReady, dc.ready, dc.onRender, dc.offRender, dc.render, dc.renderLoop, dc.renderWhen, dc.updateWhen, $document, $body

### util工具函数模块文件：src/util

  > isArray, cloneObject, pairListDict, newLine, isEven, intersect, substractSet, binarySearch, binaryInsert, numbers

### dom-util工具函数模块文件：src/dom-util

  > domField, domValue, requestAnimationFrame(dc.raf)

### extend辅助函数模块文件：src/extend

  > extend函数

****************************************************************

## 指令文件夹：src/directives/

  该文件夹定义了以下各指令，它们各自都有对应的模块文件：

  > $model, $bind, $show和$hide, $splitter, $options, $blink

## 内置部件文件夹：domcom/src/builtins/

  该文件夹定义了以下各预定义部件，它们各自都有对应的模块文件：

  > combo, dialog, triangle, autoWidthEdit, accordion

==> domcom-0.5.2.tgz: package/doc/Chinese/文件夹和模块介绍.md <==
# 代码文件夹及模块介绍

## 核心文件夹：src/core/
  部件相关的代码，包含部件基类及派生类定义、部件相关及特性相关辅助工具函数、实例化函数及Html标签函数

### 部件类文件夹：src/core/base/

  以下各组件都有各自单独对应的模块文件。

  > 部件基类：Component, BaseComponent, TransformComponent

  > 基础部件类：Tag, List, Tag, Text, Html, Comment
  
  > 变换部件类：If,Case, Cond, Func, Each, Route, Defer
  update(2016-3-16):Each部件已经被移除，直接用every, each, funcEach和mapEach函数，生成响应式List部件。
 
  > 辅助函数：toComponent和isComponent

### 部件实例化函数文件：src/core/instantiate
 > tag, txt, comment, html, if_, case_, cond, func, list, each, every, all, nTimes
 update(2016-3-16): all, nTimes已经被移除。

### 标签部件实例化函数模块文件：src/core/tag
 Html标签：
 
 > a abbr acronym address area b base bdo big blockquote body br button caption cite code col colgroup dd del dfn div dl dt em fieldset form h1 h2 h3 h4 h5 h6 head html hr i img input ins kbd label legend li link map meta noscript object ol optgroup option p param pre q samp script select small span strong style sub sup table tbody td textarea tfoot th thead title tr tt ul var header footer section

  > 不同类型的input标签函数：text, checkbox, radio, date, email, number

  更准确完整的列表请参考domcom/src/core/tag.coffee。如果有错误或者遗漏请作为bug在github issues中予以提出。

### Tag特性工具函数模块文件：src/core/property

  > classFn, styleFrom, extendAttrs, extendEventValue

*********************************************************************************************

## 文件夹：src/flow/

  包含响应函数相关代码，例如各种响应函数产生器以及其它辅助工具函数。


### 基本响应函数模块文件：src/flow/index
  本文件包含以下函数：

  > react, renewm dependent, flow, pipe, see, seeN, bind, duplex, unary, binary

### Each部件相关响应函数模块：src/flow/watch-list

  > watchEachList和watchEachObject

### 增补响应函数模块文件：src/flow/addon

  > 自动绑定：bindings
  
  > 一元运算：neg， no， bitnot， reciprocal，abs， floor，ceil， round
  
  > 二元运算：add， sub，mul，div，min
  
  > 三目运算： if_

*********************************************************************************

## 源代码根文件夹：src/

  以下直属src/文件夹的各模块包含了常用的Domcom辅助工具函数。

### DomNode类模块文件：src/DomNode

### dc直属工具函数模块文件：src/dc

  > dc, dc.directives, dc.onReady, dc.ready, dc.onRender, dc.offRender, dc.render, dc.renderLoop, dc.renderWhen, $document, $body

### util工具函数模块文件：src/util

  > isArray, cloneObject, pairListDict, newLine, isEven, intersect, substractSet, binarySearch, binaryInsert, numbers

### dom-util工具函数模块文件：src/dom-util

  > domField, domValue, requestAnimationFrame(dc.raf)

### extend辅助函数模块文件：src/extend

  > extend函数

****************************************************************

## 指令文件夹：src/directives/

  该文件夹定义了以下各指令，它们各自都有对应的模块文件：

  > $model, $bind, $show和$hide, $splitter, $options, $blink

## 内置部件文件夹：domcom/src/builtins/

  该文件夹定义了以下各预定义部件，它们各自都有对应的模块文件：

  > combo, dialog, triangle, autoWidthEdit, accordion
